#
# spec file for package python-certbot-dns-route53
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-certbot-dns-route53
Version:        3.0.1
Release:        1.1
Summary:        Route53 DNS Authenticator plugin for Certbot
License:        Apache-2.0
URL:            https://github.com/certbot/certbot
Source:         https://files.pythonhosted.org/packages/source/c/certbot-dns-route53/certbot_dns_route53-%{version}.tar.gz
BuildRequires:  %{python_module acme >= %{version}}
BuildRequires:  %{python_module boto3 >= 1.15.15}
BuildRequires:  %{python_module certbot >= %{version}}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-acme >= %{version}
Requires:       python-boto3 >= 1.15.15
Requires:       python-certbot >= %{version}
BuildArch:      noarch
%python_subpackages

%description
This certbot plugin automates the process of completing an ACME
dns-01 challenge by creating, and subsequently removing, TXT
records using AWS Route53.

%prep
%setup -q -n certbot_dns_route53-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/certbot_dns_route53
%{python_sitelib}/certbot_dns_route53-%{version}*info

%changelog
* Tue Dec  3 2024 Markéta Machová <mmachova@suse.com>
- update to version 3.0.1
  * The --dns-route53-propagation-seconds command line flag was removed.
  * The certbot_dns_route53.authenticator module has been removed. This
    should not affect any users of the plugin and instead would only
    affect developers trying to develop on top of the old code.
* Tue Jun 25 2024 Markéta Machová <mmachova@suse.com>
- update to version 2.11.0
  * sync with the main certbot package
* Fri Feb  9 2024 Dirk Müller <dmueller@suse.com>
- update to 2.9.0:
  * Support for Python 3.12 was added.
  * Updates `joinpath` syntax to only use one addition per call,
    because the multiple inputs version was causing mypy errors
    on Python 3.10.
  * Makes the `reconfigure` verb actually use the staging server
    for the dry run to check the new configuration.
* Wed Feb  7 2024 Markéta Machová <mmachova@suse.com>
- Add %%{?sle15_python_module_pythons}
* Thu Dec  7 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.8.0
  * sync with the main certbot package
* Thu Nov 16 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.7.4
  * sync with the main certbot package
* Tue Oct 31 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.7.3
  * sync with the main certbot package
* Wed Jun  7 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.6.0
  * Support for Python 3.11 was added to Certbot and all of its components.
  * All Certbot components now require pytest to run tests.
  * Packaged tests for all Certbot components besides josepy were moved inside the _internal/tests module.
  * There is now a new Other annotated challenge object to allow plugins to support entirely novel challenges.
  * --dns-route53-propagation-seconds is now deprecated. The Route53 plugin relies on the GetChange API to
    determine if a DNS update is complete. The flag has never had any effect and will be removed in a future
    version of Certbot.
  * Certbot no longer depends on zope.
* Thu Oct 27 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.31.0
  * sync with the main certbot package
* Wed Sep 21 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.30.0
  * sync with the main certbot package
* Mon Jul 11 2022 Dirk Müller <dmueller@suse.com>
- update to 1.29.0:
  * --allow-subset-of-names will now additionally retry in cases where domains
    are rejected while creating or finalizing orders. This requires subproblem
    support from the ACME server
  * The show_account subcommand now uses the "newAccount" ACME endpoint to
    fetch the account data, so it doesn't rely on the locally stored account URL.
    This fixes situations where Certbot
    would use old ACMEv1 registration info with non-functional account URLs.
  * The generated Certificate Signing Requests are now generated as version 1
    instead of version 3. This resolves situations in where strict enforcement
    of PKCS#10 meant that CSRs that were generated as version 3 were rejected
* Fri Jun 24 2022 Dirk Müller <dmueller@suse.com>
- update to version 1.28.0
  * sync with the main certbot package
* Mon May 30 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.27.0
  * sync with the main certbot package
* Fri Apr  8 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.26.0
  * certbot-dns-route53 now requires boto3>=1.15.15.
* Tue Dec 21 2021 Danilo Spinella <danilo.spinella@suse.com>
- update to version 1.22.0
  * sync with the main certbot package
* Tue Aug 10 2021 Danilo Spinella <danilo.spinella@suse.com>
- update to version 1.18.0
  * sync with the main certbot package
* Fri Jul 30 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.17.0
  * sync with the main certbot package
* Thu Jun 24 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.16.0
  * Require the latest certbot and acme plugins for simplicity
* Wed May 12 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.15.0
  * sync with the main certbot package
* Wed Apr 14 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.14.0
  * sync with the main certbot package
* Mon Mar  8 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.13.0
  * Support for Python 2 has been removed.
* Fri Jan  8 2021 Antonio Larrosa <alarrosa@suse.com>
- update to version 1.11.0
  * sync with the main certbot package
- update to version 1.10.1
  * sync with the main certbot package
- update to version 1.10.0
  * Support for Python 3.9 was added to Certbot and all of its
    components.
* Wed Oct  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.9.0
  * Sync with main certbot package.
* Fri Aug 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.7.0
  * Sync with main certbot package.
* Mon Jul 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.6.0
  * Sync with main certbot package.
* Thu Jun 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.5.0
  * Sync with main certbot package.
* Thu May 14 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.4.0
  * Sync with main certbot package.
* Wed Mar 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.3.0
  * Sync with main certbot package.
* Fri Feb 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.2.0
  * Sync with main certbot package.
* Tue Jan 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.1.0
  * Sync with main certbot package.
* Fri Jan  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.0.0
  * sync with main certbot package
* Thu Nov 14 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.40.1
  * Sync with main certbot package.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed Oct  2 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.39.0
  * Support for Python 3.8 was added to Certbot and all of its components.
* Wed Sep 11 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.38.0
  * sync with main certbot package
* Mon Aug 26 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.37.2
  * sync with main certbot package
* Wed Jul 17 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.36.0 (bsc#1141928)
  * sync with main certbot package
* Tue Jun 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.35.1
  * sync with main certbot package
* Sun May 19 2019 Dirk Mueller <dmueller@suse.com>
- update to 0.34.2:
  * sync with main certbot package
* Mon Mar 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.32.0
  * sync with main certbot package
* Fri Feb  8 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.31.0
  * sync with main certbot package
* Tue Jan 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.30.2:
  * Lockstep update together with the main package
* Fri Nov 16 2018 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.28.0
  * Test fix for Route53 plugin to prevent boto3 making outgoing
    connections.
* Wed Aug 29 2018 tchvatal@suse.com
- No need to recommend the certbot module if we require it
* Tue Aug 28 2018 tchvatal@suse.com
- Split the module from the main certbot package
